{% extends 'admin/change_list.html' %}
{% load i18n admin_urls %}
{% load admin_utils %}
{% block object-tools-items %}
    {% if has_add_permission and cl.queryset and cl.model_admin.is_adminvisualsortable %}
    <li>
        <a href="{{ cl.queryset.0|get_parent_visualorder_url }}">
            {% blocktranslate with cl.opts.verbose_name as name %}Visual Sort {{ name }}{% endblocktranslate %}
        </a>
    </li>
    {% endif %}
    {{ block.super }}
{% endblock %}
